@@ -3,7 +3,7 @@ package OpenGuides::RDF;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 use CGI::Wiki::Plugin::RSS::ModWiki;
 use Time::Piece;
@@ -112,6 +112,9 @@ sub emit_rdfxml {
         $timestamp = $time->strftime("%Y-%m-%dT%H:%M:%S");
     }
 
+    my $user_id = $username;
+    $user_id =~ s/ /_/g;
+    
     my $url               = $self->{make_node_url}->( $node_name, $version );
     my $version_indpt_url = $self->{make_node_url}->( $node_name );
     my $rdf = qq{<?xml version="1.0"?>
@@ -133,7 +136,13 @@ sub emit_rdfxml {
     <dc:title>} . $self->{site_name} . qq{: $node_name</dc:title>
     <dc:date>$timestamp</dc:date>
     <dcterms:modified>$timestamp</dcterms:modified>
-    <dc:contributor foaf:nick="$username" />
+
+    <dc:contributor>
+      <foaf:Person rdf:ID="$user_id">
+        <foaf:nick>$username</foaf:nick>
+      </foaf:Person>
+    </dc:contributor>
+
     <dc:source rdf:resource="$version_indpt_url" />
     <wiki:version>$version</wiki:version>
     <foaf:topic rdf:resource="#obj" />
@@ -154,13 +163,19 @@ sub emit_rdfxml {
       $rdf .= "    <postalCode>$postcode</postalCode>\n" if $postcode;
       $rdf .= "    <country>$country</country>\n"        if $country;
 
+    foreach (@locales)
+    { 
+      my $locale_id = $_;
+      $locale_id =~ s/ /_/g;
+   
       $rdf .= qq{
     <foaf:based_near>
-      <wn:Neighborhood>
+      <wn:Neighborhood rdf:ID="$locale_id">
         <dc:title>$_</dc:title>
       </wn:Neighborhood>
-    </foaf:based_near>\n} foreach @locales;
-
+    </foaf:based_near>\n};
+    }
+    
       if ( $latitude && $longitude ) {
           $rdf .= qq{
     <geo:lat>$latitude</geo:lat>
@@ -199,39 +214,6 @@ sub emit_rdfxml {
     return $rdf;
 }
 
-sub rss_maker {
-    my $self = shift;
-
-    # OAOO, please.
-    unless ($self->{rss_maker}) {
-        $self->{rss_maker} = CGI::Wiki::Plugin::RSS::ModWiki->new(
-          wiki                => $self->{wiki},
-          site_name           => $self->{site_name},
-          site_url            => $self->{config}->script_url,
-          site_description    => $self->{site_description},
-          make_node_url       => $self->{make_node_url},
-          recent_changes_link => $self->{config}->script_url . '?action=rc',
-          software_name       => 'OpenGuides',
-          software_homepage   => 'http://openguides.org/',
-          software_version    => $self->{og_version},
-        );
-    }
-    
-    $self->{rss_maker};
-}
-
-sub make_recentchanges_rss {
-    my ($self, %args) = @_;
-
-    $self->rss_maker->recent_changes(%args);
-}
-
-sub rss_timestamp {
-    my ($self, %args) = @_;
-    
-    $self->rss_maker->rss_timestamp(%args);
-}
-
 =head1 NAME
 
 OpenGuides::RDF - An OpenGuides plugin to output RDF/XML.
@@ -258,11 +240,6 @@ developers.
     print "Content-Type: application/rdf+xml\n\n";
     print $rdf_writer->emit_rdfxml( node => "Masala Zone, N1 0NU" );
 
-    # Ten most recent changes.
-    print "Content-Type: application/rdf+xml\n";
-    print "Last-Modified: " . $self->rss_timestamp( items => 10 ) . "\n\n";
-    print $rdf_writer->make_recentchanges_rss( items => 10 );
-
 =head1 METHODS
 
 =over 4
@@ -314,42 +291,6 @@ all of the following metadata when calling C<write_node>:
 
 =back
 
-=item B<rss_maker>
-
-Returns a raw L<CGI::Wiki::Plugin::RSS::ModWiki> object created with the values you
-invoked this module with.
-
-=item B<make_recentchanges_rss>
-
-    # Ten most recent changes.
-    print "Content-Type: application/rdf+xml\n";
-    print "Last-Modified: " . $rdf_writer->rss_timestamp( items => 10 ) . "\n\n";
-    print $rdf_writer->make_recentchanges_rss( items => 10 );
-
-    # All the changes made by bob in the past week, ignoring minor edits.
-
-    my %args = (
-                 days               => 7,
-                 ignore_minor_edits => 1,
-                 filter_on_metadata => { username => "bob" },
-               );
-
-    print "Content-Type: application/rdf+xml\n";
-    print "Last-Modified: " . $rdf_writer->rss_timestamp( %args ) . "\n\n";
-    print $rdf_writer->make_recentchanges_rss( %args );
-
-=item B<rss_timestamp>
-
-    print "Last-Modified: " . $rdf_writer->rss_timestamp( %args ) . "\n\n";
-
-Returns the timestamp of the RSS feed in POSIX::strftime style ("Tue, 29 Feb 2000 
-12:34:56 GMT"), which is equivalent to the timestamp of the most recent item
-in the feed. Takes the same arguments as make_recentchanges_rss(). You will most 
-likely need this to print a Last-Modified HTTP header so user-agents can determine
-whether they need to reload the feed or not.
-
-=back
-
 =head1 SEE ALSO
 
 =over 4
@@ -368,7 +309,7 @@ The OpenGuides Project (openguides-dev@openguides.org)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2005 The OpenGuides Project.  All Rights Reserved.
+Copyright (C) 2003-2006 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
