@@ -297,7 +297,7 @@ sub extract_metadata_vars {
     my $website = $args{metadata} ? $metadata{website}[0]
                                   : $q->param("website");
     my $formatted_website_text = "";
-    if ( $website && $website != "http://" ) {
+    if ( $website && $website ne "http://" ) {
         $formatted_website_text = $class->format_website_text(
             formatter => $formatter,
             text      => $website
